#ifndef SHARED_H
#define SHARED_H

//dummuURL is used with QNetworkManager 
const QString dummyURL = QString("ebook://get.com");
const QString OSSO_NAME = QString("mebook_osso");
enum BookViewMode{ScrollingMode, PageMode};
enum Sorting{
    byAuthor,
    byTitle,
    None
};
    


#endif
